automan: a simple automation framework
--------------------------------------

|Travis Status|  |Appveyor Status|  |Coverage Status|

.. |Travis Status| image:: https://travis-ci.org/pypr/automan.svg?branch=master
    :target: https://travis-ci.org/pypr/automan

.. |Appveyor Status| image:: https://ci.appveyor.com/api/projects/status/82mxewh71wodobdf
    :target: https://ci.appveyor.com/project/prabhuramachandran/automan

.. |Coverage Status| image:: https://codecov.io/gh/pypr/automan/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/pypr/automan


This framework allows you to automate your computational pipelines.

More details will be made available soon. To see a fully working example of a
research publication using this framework see
https://gitlab.com/prabhu/edac_sph

Features
--------

For a set of numerical simulations with a Python script one can:

- run all simulations and produce all figures with one command.
- distribute the simulations on a collection of idle computers.


The package name
----------------

The name automan comes from an old serial with the same name.  Most
other names were taken on pypi.
